{% extends "base.html.twig" %}

{% block title %}{{ 'dmarc.report.title'|trans({'report': report }) }}{% endblock %}

{% block body %}
    {% if error is not empty %}
        <p class="alert alert-error">{{ error }}</p>
        {% if raw is not empty %}
            <h3>{{ 'dmarc.raw'|trans }}</h3>
            <pre><code>{{ raw }}</code></pre>

            <br/>
            <a class="btn btn-default" href="{{ path('dmarc_report_download', {name: domain, report: report}) }}">{{ 'dmarc.download_report'|trans }}</a>
        {% endif %}
    {% else %}
        <table>
            <tbody>
                <tr>
                    <th>
                        {{ 'dmarc.provided'|trans }}
                    </th>
                    <td>
                        {{ feedback.reportMetadata.orgName }}
                        ({{ feedback.reportMetadata.email }})
                    </td>
                </tr>

                <tr>
                    <th>
                        {{ 'dmarc.report_id'|trans }}
                    </th>
                    <td>
                        {{ feedback.reportMetadata.reportId|default(('dmarc.not_defined'|trans)) }}
                    </td>
                </tr>
                <tr>
                    <th>
                        {{ 'dmarc.time'|trans }}
                    </th>
                    <td>
                        {{ feedback.reportMetadata.dateRange.begin|date('Y-m-d H:i') }} -
                        {{ feedback.reportMetadata.dateRange.end|date('Y-m-d H:i') }}
                    </td>
                </tr>
                {% if feedback.reportMetadata.extraContactInfo is not empty %}
                <tr>
                    <th>
                        {{ 'dmarc.info'|trans }}
                    </th>
                    <td>
                        {{ feedback.reportMetadata.extraContactInfo }}
                    </td>
                </tr>
                {% endif %}
            </tbody>
        </table>

        <h2>{{ 'dmarc.settings'|trans }}</h2>
        <table>
            <tr>
                <th>{{ 'dmarc.domain'|trans }}</th>
                <td>{{ feedback.policyPublished.domain }}</td>
                <th>{{ 'dmarc.dkim_alignment'|trans }}</th>
                <td>{{ feedback.policyPublished.adkim == 's' ? 'strict' : 'relaxed' }}</td>
                <th>{{ 'dmarc.spf_alignment'|trans }}</th>
                <td>{{ feedback.policyPublished.aspf == 's' ? 'strict' : 'relaxed' }}</td>

            </tr>
            <tr>
                <th>{{ 'dmarc.disposition_policy'|trans }}</th>
                <td>{{ feedback.policyPublished.p|default(('dmarc.not_defined'|trans)) }}</td>
                <th>{{ 'dmarc.subdomain_policy'|trans }}</th>
                <td>{{ feedback.policyPublished.sp|default(('dmarc.not_defined'|trans)) }}</td>
                <th>{{ 'dmarc.sampling'|trans }}</th>
                <td>{{ feedback.policyPublished.pct|default(('dmarc.not_defined'|trans)) }}%</td>
            </tr>
        </table>

        {% include 'Pro/DmarcReports/_report_rows.html.twig' %}

        <br/>
        <a class="btn btn-default" href="{{ path('dmarc_report_download', {name: domain, report: report}) }}"><i class="fa fa-download" aria-hidden="true"></i> {{ 'dmarc.download_report'|trans }}</a>

        <br/>
        <br/>
        <br/>
        <br/>
        <br/>
        <br/>
    {% endif %}

{% endblock %}

{% block javascripts %}
<script>
    $('table tbody tr').mouseenter(function() {
        if (!$(this).attr('data-auth-results')) return;
        $(this).popover({
            animation: false,
            placement: 'bottom',
            container: 'body',
            html: true,
            //selector: '[rel="popover"]', //Sepcify the selector here
            content: $(this).attr('data-auth-results')
        });
        $(this).popover('show')
    }).mouseleave(function() {
        $(this).popover('destroy')
    });
</script>
{% endblock %}
